Blob Blame History Raw
From 32b0df844e96cfff95ef2c1c7366b6b521070f24 Mon Sep 17 00:00:00 2001
From: Atin Mukherjee <amukherj@redhat.com>
Date: Thu, 16 Apr 2015 17:54:24 +0530
Subject: [PATCH 272/279] glusterd: log improvement in glusterd_peer_rpc_notify

Backport of http://review.gluster.org/#/c/11886/

If ping time out is enabled glusterd can receive a disconnect event from a peer
which has been already deleted resulting into a critical log printed. This patch
ensures that critical message is logged only when its a connect event.

Change-Id: I67d9aa3f60195e08af7dfc8a42683422aaf90a00
BUG: 1246946
Signed-off-by: Atin Mukherjee <amukherj@redhat.com>
Reviewed-on: http://review.gluster.org/10272
Tested-by: Gluster Build System <jenkins@build.gluster.com>
Reviewed-by: Gaurav Kumar Garg <ggarg@redhat.com>
Tested-by: NetBSD Build System <jenkins@build.gluster.org>
Reviewed-by: Krishnan Parthasarathi <kparthas@redhat.com>
Reviewed-on: https://code.engineering.redhat.com/gerrit/55047
Tested-by: Krishnan Parthasarathi <kparthas@redhat.com>
---
 xlators/mgmt/glusterd/src/glusterd-handler.c |   13 +++++++++----
 1 files changed, 9 insertions(+), 4 deletions(-)

diff --git a/xlators/mgmt/glusterd/src/glusterd-handler.c b/xlators/mgmt/glusterd/src/glusterd-handler.c
index ed5d6ff..c2bfcf5 100644
--- a/xlators/mgmt/glusterd/src/glusterd-handler.c
+++ b/xlators/mgmt/glusterd/src/glusterd-handler.c
@@ -5011,12 +5011,17 @@ __glusterd_peer_rpc_notify (struct rpc_clnt *rpc, void *mydata,
 
         peerinfo = glusterd_peerinfo_find_by_generation (peerctx->peerinfo_gen);
         if (!peerinfo) {
                 /* Peerinfo should be available at this point. Not finding it
                  * means that something terrible has happened
                  */
-                gf_msg (THIS->name, GF_LOG_CRITICAL, ENOENT,
+                gf_msg (THIS->name, (RPC_CLNT_CONNECT == event) ?
+                        GF_LOG_CRITICAL : GF_LOG_DEBUG, ENOENT,
                         GD_MSG_PEER_NOT_FOUND, "Could not find peer "
-                        "%s(%s)", peerctx->peername, uuid_utoa (peerctx->peerid));
+                        "%s(%s)", peerctx->peername,
+                        uuid_utoa (peerctx->peerid));
+
                 ret = -1;
                 goto out;
         }
@@ -5011,12 +5011,17 @@ __glusterd_peer_rpc_notify (struct rpc_clnt *rpc, void *mydata,
         peerinfo = glusterd_peerinfo_find_by_generation (peerctx->peerinfo_gen);
         if (!peerinfo) {
-                /* Peerinfo should be available at this point. Not finding it
-                 * means that something terrible has happened
+                /* Peerinfo should be available at this point if its a connect
+                 * event. Not finding it means that something terrible has
+                 * happened. For non-connect event we might end up having a null
+                 * peerinfo, so log at debug level.
                  */
-- 
1.7.1